==> python_ligo_lw-1.8.4.tar.gz: python_ligo_lw-1.8.4/test/ligolw_sqlite_test.sh <==
#!/bin/sh

BASE="ligolw_sqlite_test"

xmlcanonicalize () {
	for filename in "$@" ; do
		xmllint --c14n "${filename}" >"${filename}"~ && mv -f "${filename}"~ "${filename}" || return;
	done
}

#
# can ligolw_sqlite detect a missing input file?
#

echo
echo "ligolw_sqlite test 1:  detect missing input"
echo "--------------------------------------------------------------------"
rm -vf ${BASE}.sqlite
ligolw_sqlite --verbose --extract /dev/null --database ${BASE}.sqlite && exit 1
[ -f ${BASE}.sqlite ] && exit 1
echo
echo "ligolw_sqlite test 1:  success"
echo "ligolw_sqlite detected missing input and did not create an empty database"

#
# do ligolw_add and ligolw_sqlite produce identical output when used to
# merge two .xml files into a single .xml document?  confirm that URLs can
# be used to identify local source files
#

echo
echo "ligolw_sqlite test 2:  merge .xml.gz files and compare to ligolw_add"
echo "--------------------------------------------------------------------"
rm -vf ${BASE}_ref.xml ${BASE}.sqlite ${BASE}_output.xml
ligolw_add --verbose --output ${BASE}_ref.xml ${BASE}_input.xml.gz ${BASE}_input.xml.gz
ligolw_sqlite --verbose --replace --database ${BASE}.sqlite --extract ${BASE}_output.xml file://${PWD}/${BASE}_input.xml.gz ${BASE}_input.xml.gz
xmlcanonicalize ${BASE}_ref.xml ${BASE}_output.xml || exit
cmp ${BASE}_ref.xml ${BASE}_output.xml || exit
rm -vf ${BASE}.sqlite ${BASE}_output.xml
echo
echo "ligolw_sqlite test 2:  success"
echo "ligolw_add and ligolw_sqlite produced identical merged documents"

#
# does ligolw_sqlite produce the same document as above if the input
# documents are .sqlite files (converted from the original .xml input).
# confirm that URLs can be used to identify local source files
#

echo
echo "ligolw_sqlite test 3:  merge .sqlite files and compare to ligolw_add"
echo "--------------------------------------------------------------------"
ligolw_sqlite --verbose --preserve-ids --replace --database ${BASE}_input.sqlite ${BASE}_input.xml.gz
ligolw_sqlite --verbose --replace --tmp-space ${TMPDIR:-/tmp} --database ${BASE}.sqlite --extract ${BASE}_output.xml file://${PWD}/${BASE}_input.sqlite ${BASE}_input.sqlite
xmlcanonicalize ${BASE}_ref.xml ${BASE}_output.xml || exit
cmp ${BASE}_ref.xml ${BASE}_output.xml || exit
rm -vf ${BASE}_ref.xml ${BASE}_input.sqlite ${BASE}.sqlite ${BASE}_output.xml
echo
echo "ligolw_sqlite test 3:  success"
echo "ligolw_add and ligolw_sqlite produced identical merged documents"

==> python_ligo_lw-2.1.0.tar.gz: python_ligo_lw-2.1.0/test/ligolw_sqlite_test.sh <==
#!/bin/sh

BASE="ligolw_sqlite_test"

xmlcanonicalize () {
	for filename in "$@" ; do
		xmllint --c14n "${filename}" >"${filename}"~ && mv -f "${filename}"~ "${filename}" || return;
	done
}

#
# can ligolw_sqlite detect a missing input file?
#

echo
echo "ligolw_sqlite test 1:  detect missing input"
echo "--------------------------------------------------------------------"
rm -vf ${BASE}.sqlite
ligolw_sqlite --verbose --extract /dev/null --database ${BASE}.sqlite && exit 1
[ -f ${BASE}.sqlite ] && exit 1
echo
echo "ligolw_sqlite test 1:  success"
echo "ligolw_sqlite detected missing input and did not create an empty database"

#
# do ligolw_add and ligolw_sqlite produce identical output when used to
# merge two .xml files into a single .xml document?  confirm that URLs can
# be used to identify local source files
#

echo
echo "ligolw_sqlite test 2:  merge .xml.gz files and compare to ligolw_add"
echo "--------------------------------------------------------------------"
rm -vf ${BASE}_ref.xml ${BASE}.sqlite ${BASE}_output.xml
# exercise the --remove-input feature of ligolw_add while we're add it
cp ${BASE}_input.xml.gz ${BASE}_input_deleteme.xml.gz
ligolw_add --verbose --remove-input --output ${BASE}_ref.xml ${BASE}_input_deleteme.xml.gz ${BASE}_input_deleteme.xml.gz
ligolw_sqlite --verbose --replace --database ${BASE}.sqlite --extract ${BASE}_output.xml file://${PWD}/${BASE}_input.xml.gz ${BASE}_input.xml.gz
xmlcanonicalize ${BASE}_ref.xml ${BASE}_output.xml || exit
cmp ${BASE}_ref.xml ${BASE}_output.xml || exit
rm -vf ${BASE}.sqlite ${BASE}_output.xml
echo
echo "ligolw_sqlite test 2:  success"
echo "ligolw_add and ligolw_sqlite produced identical merged documents"

#
# does ligolw_sqlite produce the same document as above if the input
# documents are .sqlite files (converted from the original .xml input).
# confirm that URLs can be used to identify local source files
#

echo
echo "ligolw_sqlite test 3:  merge .sqlite files and compare to ligolw_add"
echo "--------------------------------------------------------------------"
# convert ${BASE}_input.xml.gz to ${BASE}_input.sqlite
ligolw_sqlite --verbose --preserve-ids --replace --database ${BASE}_input.sqlite ${BASE}_input.xml.gz
# overwrite ${BASE}_input.sqlite with a new database constructed from two
# copies of ${BASE}_input.sqlite, and extract result to ${BASE}_output.xml
ligolw_sqlite --verbose --replace --tmp-space ${TMPDIR:-/tmp} --database ${BASE}.sqlite --extract ${BASE}_output.xml file://${PWD}/${BASE}_input.sqlite ${BASE}_input.sqlite
# done.  result should have two copies of input, not three.  is
# ${BASE}_output.xml identical to what ligolw_add produces?
xmlcanonicalize ${BASE}_ref.xml ${BASE}_output.xml || exit
cmp ${BASE}_ref.xml ${BASE}_output.xml || exit
rm -vf ${BASE}_ref.xml ${BASE}_input.sqlite ${BASE}.sqlite ${BASE}_output.xml
echo
echo "ligolw_sqlite test 3:  success"
echo "ligolw_add and ligolw_sqlite produced identical merged documents"

echo
echo "ligolw_sqlite test 4:  other assorted tests"
echo "-------------------------------------------"
# convert ${BASE}_input.xml.gz to ${BASE}_input.sqlite
ligolw_sqlite --verbose --preserve-ids --replace --database ${BASE}_input.sqlite ${BASE}_input.xml.gz
# run tests
python3 ligolw_sqlite_test.py ${BASE}_input.sqlite || exit
rm -vf ${BASE}_input.sqlite
# clean up
